<div align="center">
  <h1 align="center">
    <img src="http://wzry-doc.pages.dev/wzry.favicon.png" width="140">
    <br/>
    WZRY · 农活自动化助手
  </h1>
</div>
<div align="center">
  <img alt="WZRY Release" src="https://img.shields.io/github/v/release/cndaqiang/WZRY?style=flat-square&color=ff7fbf&label=WZRY" />
  <img alt="Stars" src="https://img.shields.io/github/stars/cndaqiang/WZRY?style=flat-square&color=66bb6a&label=Stars" />
  <img alt="Developer" src="https://img.shields.io/badge/cndaqiang-blue?style=flat-square&color=4096d8&label=Developer" />
</div>

<div align="center">
使用方法, 请访问: <a href="https://wzry-doc.pages.dev">使用手册</a>.
<br/>
遇到问题, 请在提问前查看: <a href="https://wzry-doc.pages.dev/qa/qa/">常见问题</a>.
</div>

## WZRY

[WZRY](https://github.com/cndaqiang/WZRY)是基于[airtest-mobileauto](https://github.com/cndaqiang/airtest_mobileauto)开发的王者荣耀农活自动化免费开源脚本. 


## 自动化
真正的无人值守：自动对战、领取礼包、更新游戏、错误纠正

* 开启关闭模拟器、容器、手机
* 自动检测处理游戏闪退、模拟器关闭等各种错误
* 健康系统自动休息启动
* 自动切换熟练度,优先星耀人机模式,次数达到上限后切换青铜人机
* 自动调整分路并选择熟练度最低的英雄

## 对战模式

5v5人机单人模式、组队模式、标准模式、快速模式、星耀难度、青铜难度

- 挂机模式: 适合完成每日任务、战令任务、**提高熟练度**
- TOUCH模式(移动+平A): 适合完成活动的**标准对战非挂机**对战要求

王者模拟战单人模式、组队模式

- 刷信誉分专用, 每日上限+5分. 
- 战令的每期任务: 20场娱乐模式, 可以用模拟战刷齐



## 礼包功能

* 友情对战: 友情币领取、奖励兑换
* 邮件礼包: 好友邮件、系统邮件
* 妲己一键领奖
* 战令礼包、战令任务礼包
* 回忆礼册、灵宝互动
* 祈愿页面领取祈愿币、玉镖夺魁的飞镖
* 王者营地礼包
* 王者体验服礼包
* KPL观赛战令观赛领取经验升级
* 战队商店领取英雄碎片
* 商城每日免费钻石碎片随机礼包

## 致谢
- *[Cloudiiink](https://github.com/Cloudiiink) 正在设计制作全新的项目图标，版权归其所有。*  
  特别感谢 Cloudiiink 的精心创作！  

- 灵感和支持来自以下项目：  
  - [airtest_mobileauto](https://github.com/cndaqiang/airtest_mobileauto)  
  - [WZRY_AirtestIDE](https://github.com/XRSec/WZRY_AirtestIDE)  
  - [Airtest Project](https://github.com/AirtestProject)

- 感谢所有提问 issue 和为本项目打星的用户！

